pub struct Platform(/* private fields */);Expand description
Abstraction for SYCL platform.
The Platform struct encapsulates a single SYCL platform on which SYCL kernel functions may be executed.
A SYCL platform must be associated with a single SYCL backend.
A Platform is also associated with one or more SYCL devices associated with the same SYCL backend.
Implementations
Sourceimpl Platform
impl Platform
Sourcepub fn get_platforms() -> Vec<Self>
pub fn get_platforms() -> Vec<Self>
Returns a Vec containing all SYCL platforms from all SYCL backends available in the system.
Sourcepub fn get_devices(&self) -> Vec<Device>
pub fn get_devices(&self) -> Vec<Device>
Returns a Vec containing all the root devices associated with this Platform.
Sourcepub fn get_info<T: PlatformInfo>(&self) -> T::Item
pub fn get_info<T: PlatformInfo>(&self) -> T::Item
Queries this Platform for information requested by the generic parameter Param.
The associated type Param::Item must be defined in accordance with the info parameters
in oneapi_rs::info::platform to facilitate returning the type associated with the Param parameter.